@@ -23,7 +23,7 @@ class XAI(BaseModel):
 
         self.__api_client = APIClient(
             debug=True,
-            base_url='http://3.108.15.217:30010'
+            base_url='https://api-m.aryaxai.com'
         )
 
 
